@@ -1079,19 +1079,19 @@ class PlaceService(BaseRdbmsService):
 
             row = cursor.fetch_one()
             if row is None:
-                raise self.UndefinedObjectException(
-                    "The specified place is not registered to the platform",
-                    payload={'place_id': place_id})
+                raise self.UndefinedObjectException(f"The place {place_id} does not exist")
 
             # Build the instance containing the information of the place.
             place = row.get_object({
                 'account_id': cast.string_to_uuid,
+                'agent_id': cast.string_to_uuid,
                 'cover_photo_id': cast.string_to_uuid,
                 'creation_time': cast.string_to_timestamp,
-                'agent_id': cast.string_to_uuid,
+                'picture_ud': cast.string_to_uuid,
+                'place_id': cast.string_to_uuid,
                 'team_id': cast.string_to_uuid,
                 'update_time': cast.string_to_timestamp,
-                'place_id': cast.string_to_uuid })
+            })
 
             # Check whether the place is currently enable, and raise an exception
             # if not.
@@ -1101,12 +1101,10 @@ class PlaceService(BaseRdbmsService):
                 elif place.object_status == ObjectStatus.deleted:
                     raise self.DeletedObjectException()
 
-            # Build the Uniform Resource Locator (URL) of the place's cover photo,
-            # if any.
-            place.cover_photo_url = place.cover_photo_id and os.path.join(
-                settings.CDN_URL_HOSTNAME,
-                self.DEFAULT_CDN_BUCKET_NAME_PHOTO,
-                str(place.cover_photo_id))
+            # Build the Uniform Resource Locators (URL) of the place's logo and
+            # cover photo.
+            place.picture_url = self.build_picture_url(place.picture_url)
+            place.cover_photo_url = self.build_cover_photo_url(place.cover_photo_id)
 
             # Build the geographical location of the place.
             if place.longitude and place.latitude:
